| Title: | Contains the Trained 'text2sdg' Ensemble Model Data |
|---|---|
| Description: | This is a companion package for the 'text2sdg' package. It contains the trained ensemble models needed by the 'detect_sdg' function from the 'text2sdg' package. See Wulff, Meier and Mata (2023) <arXiv:2301.11353> and Meier, Wulff and Mata (2021) <arXiv:2110.05856> for reference. |
| Authors: | Dominik S. Meier [aut, cre] (ORCID: <https://orcid.org/0000-0002-3999-1388>) |
| Maintainer: | Dominik S. Meier <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.1 |
| Built: | 2026-05-17 09:48:50 UTC |
| Source: | https://github.com/psychobas/text2sdgdata |
ranger::ranger() random forest models that are used by the text2sdg detect_sdg() function.Ensemble models based on a random forest architecture that pools the predictions of six labeling systems generated using the detect_sdg_systems() function from the text2sdg package and also considers text length.
ensemblesensembles
An object of class list of length 4.
Wulff, D. U., Meier, D., & Mata, R. (2023). Using novel data and ensemble models to improve automated SDG-labeling. arXiv